'
' fixcl.vbs - clean files leftover or made obsolete by fix
' Copyright (c) 2023 SAS Institute Inc.
'
'

' command-line options
Set args = WScript.Arguments
fixID = ""
debugMode = False
if args.Count > 0 Then
    if args.Count > 1 Then
        If args(0) = "-d" Then
	    debugMode = True
        Else
            WScript.Echo "usage: fixcl.vbs [-d] <fixid>"
            WScript.Quit 1
        End If
        fixID = args(1)
    Else
        fixID = args(0)
    End If
End If
If fixID = "" Then
    WScript.Echo "usage: fixcl.vbs <fixid>"
    WScript.Quit 1
End If

' print a diagnostic message
Sub debugPrint(msg) 
    If debugMode Then
        WScript.Echo "[debug] " & msg
    End If
End Sub

' start message
WScript.Echo "cleaning files for patch fix" & fixID & "..."

' find root of installation 
Set fso = CreateObject("Scripting.FileSystemObject")
bindir = fso.GetFile(WScript.ScriptFullName).ParentFolder
home = fso.GetFolder(bindir).ParentFolder

' file locations
diDir = home & "\data\install"
rmList = diDir & "\remove.fix" & fixID & ".meta"

' counters for file remove operations
numFound = 0
numRemoved = 0

' read remove list and remove any matching file from install
debugPrint("reading " & rmList)
If fso.FileExists(rmList) Then
    Set file = fso.GetFile(rmList)
    Set stream = file.OpenAsTextStream(1, 0)
    On Error Resume Next
    While Not stream.AtEndOfStream 
        line = stream.ReadLine
        Trim(line)
        If Left(line, 1) <> "#" Then
            ' not a comment
            filePath = home & "\" & line
            debugPrint("checking " & filePath)
            If fso.FileExists(filePath) Then
                numFound = numFound + 1
                WScript.Echo "removing " & filePath
                fso.DeleteFile(filePath)
                If Err Then
                    WScript.Echo "error: " & Err.Description
                Else
                    numRemoved = numRemoved + 1
                End If
            End If
        End If
    Wend
    On Error Goto 0
Else
    debugPrint("no remove list found for fix" & fixID)
End If

' print results
If numFound > 0 Then
    WScript.Echo "removed " & numRemoved & " files"
Else
    WScript.Echo "no files to remove"
End If
WScript.Quit 0

